==> cxf-testutils-2.0.10.0-fuse-sources.jar: org/apache/type_test/xml/TestSimpleAll.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.SimpleAll;


/**
 * <p>Java class for testSimpleAll element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testSimpleAll">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}SimpleAll"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}SimpleAll"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testSimpleAll")
public class TestSimpleAll {

    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected SimpleAll x;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected SimpleAll y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleAll }
     *     
     */
    public SimpleAll getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleAll }
     *     
     */
    public void setX(SimpleAll value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleAll }
     *     
     */
    public SimpleAll getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleAll }
     *     
     */
    public void setY(SimpleAll value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.18-fuse-sources.jar: org/apache/type_test/xml/TestSimpleAll.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.SimpleAll;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}SimpleAll"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}SimpleAll"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testSimpleAll")
public class TestSimpleAll {

    @XmlElement(required = true)
    protected SimpleAll x;
    @XmlElement(required = true)
    protected SimpleAll y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleAll }
     *     
     */
    public SimpleAll getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleAll }
     *     
     */
    public void setX(SimpleAll value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link SimpleAll }
     *     
     */
    public SimpleAll getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link SimpleAll }
     *     
     */
    public void setY(SimpleAll value) {
        this.y = value;
    }

}
